@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009 Net-ng.
+# Copyright (c) 2008, 2009, 2010 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -31,11 +31,11 @@ class Photo(object):
         """Return the title of the photo"""
         return PhotoData.get(self.id).title
 
-    def img(self, h=None):
+    def img(self):
         """Return the image data"""
         return str(PhotoData.get(self.id).img)
 
-    def thumbnail(self, h=None):
+    def thumbnail(self):
         """Return the thumbnail data"""
         return str(PhotoData.get(self.id).thumbnail)
 
