@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009 Net-ng.
+# Copyright (c) 2008, 2009, 2010 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -26,10 +26,10 @@ class Photo(object):
     def title(self):
         return PhotoData.get(self.id).title
 
-    def img(self, h=None):
+    def img(self):
         return str(PhotoData.get(self.id).img)
 
-    def thumbnail(self, h=None):
+    def thumbnail(self):
         return str(PhotoData.get(self.id).thumbnail)
 
 @presentation.render_for(Photo)
