@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009 Net-ng.
+# Copyright (c) 2008, 2009, 2010 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -25,10 +25,10 @@ class Photo(object):
     def title(self):
         return PhotoData.get(self.id).title
 
-    def img(self, h=None):
+    def img(self):
         return str(PhotoData.get(self.id).img)
 
-    def thumbnail(self, h=None):
+    def thumbnail(self):
         return str(PhotoData.get(self.id).thumbnail)
 
 @presentation.render_for(Photo)
@@ -57,7 +57,7 @@ class PhotoCreator(editor.Editor):
     def commit(self, comp):
         """After the submission of the form, the PhotoCreator answers the
            tuple (title of the photo, image data)"""
-        comp.answer((self.title(), self.img.value))
+        comp.answer((self.title(), self.img.value.file.read()))
 
 @presentation.render_for(PhotoCreator)
 def render(self, h, comp, *args):
