@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009 Net-ng.
+# Copyright (c) 2008, 2009, 2010 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -29,7 +29,7 @@ class Image(object):
         self.title = title
         self.url = url
         
-    def send_image(self, h):
+    def send_image(self):
         """Read the image data
         
         In:
