@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009 Net-ng.
+# Copyright (c) 2008, 2009, 2010 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -19,6 +19,7 @@ from nagare.namespaces import xhtml
 from nagare.examples import counter, calculator, tictactoe
 from nagare.examples.wiki import wiki9
 from nagare.examples.gallery import gallery7
+from nagare.examples.jewels import Jewels
 
 class Portal(object):
     """The ``Portal`` object is only a container"""
@@ -29,6 +30,7 @@ class Portal(object):
         self.counter = component.Component(counter.Counter1())
         self.tictactoe = component.Component(tictactoe.Task())
         self.wiki = component.Component(wiki9.app())
+        self.jewels = component.Component(Jewels(15, 10))
         self.gallery = component.Component(gallery7.app())
 
 
@@ -40,19 +42,19 @@ def render(self, h, *args):
     h.head.javascript_url(ajax.YUI_EXTERNAL_PREFIX + '/yahoo-dom-event/yahoo-dom-event.js')
     h.head.javascript_url(ajax.YUI_EXTERNAL_PREFIX + '/dragdrop/dragdrop.js')
     h.head.javascript_url(ajax.YUI_EXTERNAL_PREFIX + '/dom/dom.js')
-    
+
     h.head.javascript_url('portal.js')
     h.head.css_url('portal.css')
-    
+
     h.head << h.head.title('Portal demonstration')
-    
+
     with h.div(id='portal', class_='FixedWidth'):
 
         # Each column must be a <div> with the class 'portletColumn'
         with h.div(class_='portletColumn'):
             # Each portlet must be a <div> with the class 'portlet'
             with h.div(class_='portlet'):
-                # Each D&D portlet handle must be a <div> with the class 'portletHandle' 
+                # Each D&D portlet handle must be a <div> with the class 'portletHandle'
                 h << h.div('About', class_='portletHandle')
                 with h.div:
                     h << h.p('This is a simple prototype of a dashboard that allows you to reorder containers much like iGoogle')
@@ -67,17 +69,25 @@ def render(self, h, *args):
             with h.div(class_='portlet'):
                 h << h.div('RPN Calculator', class_='portletHandle')
                 h << self.calc.render(xhtml.AsyncRenderer(h))
-        
+
         with h.div(class_='portletColumn'):
             with h.div(class_='portlet'):
                 h << h.div('TicTacToe', class_='portletHandle')
-                h << self.tictactoe.render(xhtml.AsyncRenderer(h))             
-        
+                h << self.tictactoe.render(xhtml.AsyncRenderer(h))
+
             with h.div(class_='portlet'):
                 h << h.div('Wiki', class_='portletHandle')
                 h << self.wiki.render(xhtml.AsyncRenderer(h))
                 h << h.p(style='clear: both')
 
+            with h.div(class_='portlet'):
+                h << h.div('Jewels', class_='portletHandle')
+
+                h.head.css_url('jewels.css')
+                h << h.div(self.jewels.render(xhtml.AsyncRenderer(h)), class_='jewels')
+
+                h << h.p(style='clear: both')
+
         with h.div(class_='portletColumn'):
             with h.div(class_='portlet'):
                 h << h.div('Photos gallery', class_='portletHandle')
@@ -86,7 +96,7 @@ def render(self, h, *args):
 
         # Initialize the portal
         h << h.script('portalInit("portal")', type='text/javascript')
-            
+
     return h.root
 
 # ---------------------------------------------------------------------------
